# ksns
Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Ratul (c) 2021

## Examples of How To Use (Alpha Version)

Install from pypi

```python
pip3 install ksns
```

Creating A Build

```python
pip3 install --editable .
```

Run commands

```python
ksns ➤ python3 -m ksns

Usage: python -m ksns [OPTIONS] COMMAND [ARGS]...

Options:
  --help  Show this message and exit.

Commands:
  list  List of namespaces in context
  ns    Switch to another namespace: <namespace_name>
```